<?php

defined('ABSPATH') || exit;

/**
 * FSSC Meta Field Class. 
 *
 * @class FSSC_Fields
 */
class FSSC_Fields{
	/**
	 *
	 * Get schema Fields
	 *
	 */
	function getSchemaFields() {
        $server_url = get_option('_fspi_server_url').'/products';
		$schemaFields = array(
			'article'=> array(
                'title'  => __("Article", "fs-schema-wordpress"),
                'fields' => array(
                    'active'       => array(
                        'type' => 'checkbox'
                    ),
                    'headline'            => array(
                        'title'    => __('Headline', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'desc'     => __('Article title', "fs-schema-wordpress"),
                        'required' => true
                    ),
                    'mainEntityOfPage'    => array(
                        'title'    => __('Page URL', "fs-schema-wordpress"),
                        'type'     => 'url',
                        'desc'     => __('The canonical URL of the article page', "fs-schema-wordpress"),
                        'required' => true
                    ),
                    'author'              => array(
                        'title'    => __('Author Name', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'desc'     => __('Author display name', "fs-schema-wordpress"),
                        'required' => true
                    ),
                    'image'               => array(
                        'title'    => __('Article Feature Image', "fs-schema-wordpress"),
                        'type'     => 'image',
                        'required' => true,
                        'desc'     => __('Images should be at least 1200 pixels wide.<br>Images should be in .jpg, .png, or. gif format.', "fs-schema-wordpress"),
                        'multiple' => true
                    ),
                    'datePublished'       => array(
                        'title'    => __('Published date', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'required' => true,
                        'desc'     => __('Like this: 2020-01-01 12:00 PM', "fs-schema-wordpress")
                    ),
                    'dateModified'        => array(
                        'title'    => __('Modified date', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'required' => true,
                        'desc'     => __('Like this: 2020-01-01 12:00 PM', "fs-schema-wordpress")
                    ),
                    'publisher'           => array(
                        'title'    => __('Publisher', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'desc'     => __('Publisher name or Organization name', "fs-schema-wordpress"),
                        'required' => true
                    ),
                    'publisherImage'      => array(
                        'title'    => __('Publisher Logo', "fs-schema-wordpress"),
                        'type'     => 'image',
                        'use'      => 'logo',
                        'desc'     => __('The logo must be a rectangle, not a square.<br>The logo should fit in a 60x600px rectangle, and <br> either be exactly 60px high (preferred), or exactly 600px wide.', "fs-schema-wordpress"),
                        'required' => true
                    ),
                    'description'         => array(
                        'title' => __('Description', "fs-schema-wordpress"),
                        'type'  => 'textarea',
                        'desc'  => __('A short description of the article.', "fs-schema-wordpress")
                    )
                )
            ),
            'product' => array(
                'title' => __("Product", "fs-schema-wordpress"),
                'description' => __("Autofill applied only for first 10 products, To allow more products please purchase our plan <a href='".$server_url."' target='_blank'>Click Here</a>", "fs-schema-wordpress"),
                'fields' => array(
                    'active'       => array(
                        'type' => 'checkbox'
                    ),
                    'name'              => array(
                        'title'    => __('Name', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'required' => true,
                        'desc'     => __("The name of the product.", "fs-schema-wordpress")
                    ),
                    'image'             => array(
                        'title' => __('Image', "fs-schema-wordpress"),
                        'type'  => 'image',
                        'desc'  => __("The URL of a product photo. Pictures clearly showing the product, e.g. against a white background, are preferred.", "fs-schema-wordpress")
                    ),
                    'description'       => array(
                        'title' => __('Description', "fs-schema-wordpress"),
                        'type'  => 'textarea',
                        'desc'  => __("Product description.", "fs-schema-wordpress")
                    ),
                    'sku'             => array(
                        'title'       => __('SKU', "fs-schema-wordpress"),
                        'type'        => 'text',
                        'recommended' => true
                    ),
                    'brand'           => array(
                        'title'       => __('Brand', "fs-schema-wordpress"),
                        'type'        => 'text',
                        'recommended' => true,
                        'desc'        => __("The brand of the product.", "fs-schema-wordpress")
                    ),
                    'identifier_type'   => array(
                        'title'       => __('Identifier Type', "fs-schema-wordpress"),
                        'type'        => 'select',
                        'recommended' => true,
                        'options'     => array(
                            'mpn'    => 'MPN',
                            'isbn'   => 'ISBN',
                            'gtin8'  => 'GTIN-8 (UPC, JAN)',
                            'gtin12' => 'GTIN-12 (UPC)',
                            'gtin13' => 'GTIN-13 (EAN,JAN)'
                        ),
                        'desc'        => __("<strong>MPN</strong><br>
                                       &#8594; MPN(Manufacturer Part Number) Used globally, Alphanumeric digits (various lengths)<br>
                                       <strong>GTIN</strong><br>
                                       &#8594; UPC(Universal Product Code) Used in primarily North America. 12 numeric digits. eg. 892685001003.<br>
                                       &#8594; EAN(European Article Number) Used primarily outside of North America. Typically 13 numeric digits (can occasionally be either eight or 14 numeric digits). eg. 4011200296908<br>
                                       &#8594; ISBN(International Standard Book Number) Used globally, ISBN-13 (recommended), 13 numeric digits 978-0747595823<br>
                                       &#8594; JAN(Japanese Article Number) Used only in Japan, 8 or 13 numeric digits.", "fs-schema-wordpress")
                    ),
                    'identifier'        => array(
                        'title'       => __('Identifier', "fs-schema-wordpress"),
                        'type'        => 'text',
                        'recommended' => true,
                        'desc'        => __("Enter product unique identifier", "fs-schema-wordpress")
                    ),
                    'ratingValue'     => array(
                        'title'       => __('Rating Value', "fs-schema-wordpress"),
                        'type'        => 'number',
                        'recommended' => true,
                        'desc'        => __("Rating value of the product.", "fs-schema-wordpress")
                    ),
                    'ratingCount'     => array(
                        'title'       => __('Rating count', "fs-schema-wordpress"),
                        'type'        => 'number',
                        'recommended' => true,
                        'desc'        => __("Rating count of the product.", "fs-schema-wordpress")
                    ),
                    'reviewRatingValue' => array(
                        'title'       => __('Review rating value', "fs-schema-wordpress"),
                        'type'        => 'number',
                        'recommended' => true,
                        'attr'        => 'step="any"',
                        'desc'        => __("Rating value. (1 , 2.5, 3, 5 etc)", "fs-schema-wordpress")
                    ),
                    'reviewBestRating'  => array(
                        'title'       => __('Review Best rating', "fs-schema-wordpress"),
                        'type'        => 'number',
                        'recommended' => true,
                        'attr'        => 'step="any"',
                    ),
                    'reviewAuthor'    => array(
                        'title'       => __('Review author', "fs-schema-wordpress"),
                        'type'        => 'text'
                    ),
                    'price'             => array(
                        'title' => __('Price', "fs-schema-wordpress"),
                        'type'  => 'number',
                        'attr'  => 'step="any"',
                        'desc'  => __("The lowest available price, including service charges and fees, of this type of ticket.", "fs-schema-wordpress")
                    ),
                    'priceValidUntil'   => array(
                        'title'       => __('PriceValidUntil', "fs-schema-wordpress"),
                        'type'        => 'text',
                        'recommended' => true,
                        'class'       => 'kcseo-date',
                        'desc'        => __("The date in '2020-11-05' format after which the price will no longer be available.", "fs-schema-wordpress")
                    ),
                    'priceCurrency'     => array(
                        'title' => __('Price currency', "fs-schema-wordpress"),
                        'type'  => 'text',
                        'desc'  => __("Currency code like USD, GBP, EUR.", "fs-schema-wordpress")
                    ),
                    'availability'      => array(
                        'title'   => 'Availability',
                        'type'    => 'select',
                        'empty'   => "Select one",
                        'options' => array(
                            'http://schema.org/InStock'             => 'In stock',
                            'http://schema.org/InStoreOnly'         => 'In store only',
                            'http://schema.org/OutOfStock'          => 'Out of Stock',
                            'http://schema.org/SoldOut'             => 'Sold out',
                            'http://schema.org/OnlineOnly'          => 'Online only',
                            'http://schema.org/LimitedAvailability' => 'Limited availability',
                            'http://schema.org/Discontinued'        => 'Discontinued',
                            'http://schema.org/PreOrder'            => 'Preorder',
                        ),
                        'desc'    => __("Select a availability type", "fs-schema-wordpress")
                    ),
                    'itemCondition'     => array(
                        'title'   => 'Product condition',
                        'type'    => 'select',
                        'empty'   => "Select one",
                        'options' => array(
                            'http://schema.org/NewCondition'         => 'NewCondition',
                            'http://schema.org/UsedCondition'        => 'UsedCondition',
                            'http://schema.org/DamagedCondition'     => 'DamagedCondition',
                            'http://schema.org/RefurbishedCondition' => 'RefurbishedCondition',
                        ),
                        'desc'    => __("Select a condition", "fs-schema-wordpress")
                    ),
                    'url'               => array(
                        'title' => __('Product URL', "fs-schema-wordpress"),
                        'type'  => 'url',
                        'desc'  => __("A URL to the product web page (that includes the Offer). (Don't use offerURL for markup that appears on the product page itself.)", "fs-schema-wordpress")
                    )
                )
            ),
            'video'      => array(
                'title'  => __('Video', "fs-schema-wordpress"),
                'fields' => array(
                    'active'           => array(
                        'type' => 'checkbox'
                    ),
                    'name'             => array(
                        'title'    => __('Name', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'required' => true,
                        'desc'     => __("The title of the video", "fs-schema-wordpress")
                    ),
                    'description'      => array(
                        'title'    => __('Description', "fs-schema-wordpress"),
                        'type'     => 'textarea',
                        'required' => true,
                        'desc'     => __("The description of the video", "fs-schema-wordpress")
                    ),
                    'thumbnailUrl'     => array(
                        'title'       => 'Thumbnail URL',
                        'type'        => 'url',
                        'placeholder' => "URL",
                        'required'    => true,
                        'desc'        => __("A URL pointing to the video thumbnail image file. Images must be at least 160x90 pixels and at most 1920x1080 pixels.", "fs-schema-wordpress")
                    ),
                    'uploadDate'       => array(
                        'title' => __('Updated date', "fs-schema-wordpress"),
                        'type'  => 'text',
                        'class' => 'kcseo-date',
                        'desc'  => __('Like this: 2020-01-01', "fs-schema-wordpress")
                    ),
                    'duration'         => array(
                        'title' => __('Duration', "fs-schema-wordpress"),
                        'type'  => 'text',
                        'desc'  => __("The duration of the video in ISO 8601 format.(PT1M33S)", "fs-schema-wordpress")
                    ),
                    'contentUrl'       => array(
                        'title'       => 'Content URL',
                        'type'        => 'url',
                        'placeholder' => 'URL',
                        'desc'        => __("A URL pointing to the actual video media file. This file should be in .mpg, .mpeg, .mp4, .m4v, .mov, .wmv, .asf, .avi, .ra, .ram, .rm, .flv, or other video file format.", "fs-schema-wordpress")
                    ),
                    'embedUrl'         => array(
                        'title'       => 'Embed URL',
                        'placeholder' => 'URL',
                        'type'        => 'url',
                        'desc'        => __("A URL pointing to a player for the specific video. Usually this is the information in the src element of an < embed> tag.Example: Dailymotion: http://www.dailymotion.com/swf/x1o2g.", "fs-schema-wordpress")
                    ),
                    'interactionCount' => array(
                        'title' => __('Interaction count', "fs-schema-wordpress"),
                        'type'  => 'text',
                        'desc'  => __("The number of times the video has been viewed.", "fs-schema-wordpress")
                    ),
                    'expires'          => array(
                        'title' => __('Expires', "fs-schema-wordpress"),
                        'type'  => 'text',
                        'class' => 'kcseo-date',
                        'desc'  => __("Like this: 2020-01-01 4:00 PM", "fs-schema-wordpress")
                    ),
                )
            ),
            'localBusiness' => array(
                'title' => __("Local Business", "fs-schema-wordpress"),
                'fields' => array(
                    'active'           => array(
                        'type' => 'checkbox'
                    ),
                    'business_type'         => array(
                        'title'    => __('Type of Business', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'required' => true,
                        'desc'     => __("Type of Business i.e Restaurant", "fs-schema-wordpress")
                    ),
                    'name'         => array(
                        'title'    => __('Name', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'required' => true,
                        'desc'     => __("Name of Business ", "fs-schema-wordpress")
                    ),
                    'description'   => array(
                        'title'     => __('Description', "fs-schema-wordpress"),
                        'type'      => 'textarea',
                        'desc'      => __("The description about the Business", "fs-schema-wordpress")
                    ),
                    'image'        => array(
                        'title'    => __('Image', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'desc'     => __("Url of the image", "fs-schema-wordpress")
                    ),
                    'streetAddress'        => array(
                        'title'    => __('Street Address', "fs-schema-wordpress"),
                        'type'     => 'text'
                    ),
                    'addressLocality'        => array(
                        'title'    => __('Address Locality', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'desc'     => __("City", "fs-schema-wordpress")
                    ),
                    'addressRegion'        => array(
                        'title'    => __('Address Region', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'desc'     => __("State like MH, NY", "fs-schema-wordpress")
                    ),
                    'postalCode'   => array(
                        'title'    => __('Postal Code', "fs-schema-wordpress"),
                        'type'     => 'text',
                    ),
                    'addressCountry' => array(
                        'title'      => __('Address Country', "fs-schema-wordpress"),
                        'type'       => 'text',
                        'desc'       => __("Country like IN, US, UK", "fs-schema-wordpress")
                    ),
                    'telephone'    => array(
                        'title'    => __('Phone Number', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'required' => true,
                    ),
                    'map'          => array(
                        'title'    => __('Map URL', "fs-schema-wordpress"),
                        'type'     => 'text',
                    ),
                    'priceRange'        => array(
                        'title'    => __('Price Range', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'required' => true,
                        'desc'     => __("The relative price range of a business, commonly specified by either a numerical range (for example, '$10-15') or a normalized number of currency signs (for example, '$$$')", "fs-schema-wordpress")
                    ),
                )
            ),
            'JobPosting'       => array(
                'title' => __("Job Posting", "fs-schema-wordpress"),
                'fields' => array(
                    'active'           => array(
                        'type' => 'checkbox'
                    ),
                    'title'         => array(
                        'title'    => __('Title', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'required' => true,
                        'desc'     => __("Title of job ", "fs-schema-wordpress")
                    ),
                    'description'   => array(
                        'title'     => __('Description', "fs-schema-wordpress"),
                        'type'      => 'textarea'
                    ),
                    'identifier_name'         => array(
                        'title'    => __('Name', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'desc'     => __("Organization's unique identifier for the job.", "fs-schema-wordpress")
                    ),
                    'identifier_value'         => array(
                        'title'    => __('Value', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'required' => true,
                        'desc'     => __("The value of the quantitative value or property value node.", "fs-schema-wordpress")
                    ),
                    'datePosted'    => array(
                        'title'     => __('Posted date', "fs-schema-wordpress"),
                        'type'      => 'text',
                        'desc'      => __('Like this: 2020-01-01', "fs-schema-wordpress")
                    ),
                    'validThrough'  => array(
                        'title'     => __('Valid Through', "fs-schema-wordpress"),
                        'type'      => 'text',
                        'desc'      => __('Like this: 2020-01-01', "fs-schema-wordpress")
                    ),
                    'employmentType' => array(
                        'title'      => __('Employment Type', "fs-schema-wordpress"),
                        'type'       => 'text'
                    ),
                    'organization_section'   => array(
                        'title'     => __('Hiring Organization Details', "fs-schema-wordpress"),
                        'type'      => 'heading'
                    ),
                    'organization_name' => array(
                        'title'      => __('Name', "fs-schema-wordpress"),
                        'type'       => 'text'
                    ),
                    'sameAs' => array(
                        'title'      => __('URL', "fs-schema-wordpress"),
                        'type'       => 'text'
                    ),
                    'image' => array(
                        'title'      => __('Logo', "fs-schema-wordpress"),
                        'type'       => 'image'
                    ),
                    'location_section'   => array(
                        'title'     => __('Location Details', "fs-schema-wordpress"),
                        'type'      => 'heading'
                    ),
                    'streetAddress'        => array(
                        'title'    => __('Street Address', "fs-schema-wordpress"),
                        'type'     => 'text'
                    ),
                    'addressLocality'        => array(
                        'title'    => __('Address Locality', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'desc'     => __("City", "fs-schema-wordpress")
                    ),
                    'addressRegion'        => array(
                        'title'    => __('Address Region', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'desc'     => __("State like MH, NY", "fs-schema-wordpress")
                    ),
                    'postalCode'        => array(
                        'title'    => __('Postal Code', "fs-schema-wordpress"),
                        'type'     => 'text',
                    ),
                    'addressCountry'        => array(
                        'title'    => __('Address Country', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'desc'     => __("Country like IN, US, UK", "fs-schema-wordpress")
                    ),
                    'salary_section'   => array(
                        'title'     => __('Salary Details', "fs-schema-wordpress"),
                        'type'      => 'heading'
                    ),
                    'currency'        => array(
                        'title'    => __('Currency', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'desc'     => __("Currency like USD, EUR, GBP", "fs-schema-wordpress")
                    ),
                    'salary'        => array(
                        'title'    => __('Value', "fs-schema-wordpress"),
                        'type'     => 'text',
                    ),
                    'unitText'        => array(
                        'title'   => 'Mode',
                        'type'    => 'select',
                        'empty'   => "Select mode",
                        'options' => array(
                            'HOUR'  => 'HOUR',
                            'DAY'   => 'DAY',
                            'WEEK'  => 'WEEK',
                            'MONTH' => 'MONTH',
                            'YEAR'  => 'YEAR',
                        )
                    )
                )
            ),
            'event' => array(
                'title'  => __("Event", "fs-schema-wordpress"),
                'fields' => array(
                    'active'               => array(
                        'type' => 'checkbox'
                    ),
                    'name'                 => array(
                        'title'    => __('Name', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'required' => true,
                        'desc'     => __("The name of the event.", "fs-schema-wordpress")
                    ),
                    'startDate'            => array(
                        'title'    => __('Start date', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'required' => true,
                        'desc'     => __("Event start date Like : 2020-01-01 4:00 AM", "fs-schema-wordpress")
                    ),
                    'endDate'              => array(
                        'title'       => __('End date', "fs-schema-wordpress"),
                        'type'        => 'text',
                        'recommended' => true,
                        'desc'        => __("Event start date Like : 2020-01-01 4:00 AM", "fs-schema-wordpress")
                    ),
                    'description'          => array(
                        'title'       => __('Description', "fs-schema-wordpress"),
                        'type'        => 'textarea',
                        'recommended' => true,
                        'desc'        => __("Event description", "fs-schema-wordpress")
                    ),
                    'image'                => array(
                        'title'       => __('Image URL', "fs-schema-wordpress"),
                        'type'        => 'url',
                        'recommended' => true,
                        'desc'        => __("URL of an image or logo for the event or tour", "fs-schema-wordpress")
                    ),
                    'url'                  => array(
                        'title'       => 'URL',
                        'recommended' => true,
                        'type'        => 'url',
                        'placeholder' => 'URL',
                        'desc'        => __("A link to the event's details page.", "fs-schema-wordpress")
                    ),
                    'locationName'         => array(
                        'title'    => __('Location name', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'required' => true,
                        'desc'     => __("Event Location name", "fs-schema-wordpress")
                    ),
                    'locationAddress'      => array(
                        'title'    => __('Location address', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'required' => true,
                        'desc'     => __("The location of for example where the event is happening, an organization is located, or where an action takes place.", "fs-schema-wordpress")
                    ),
                    'performerName'        => array(
                        'title'       => __('Performer Name', "fs-schema-wordpress"),
                        'type'        => 'text',
                        'recommended' => true,
                        'desc'        => __("The performer's name.", "fs-schema-wordpress")
                    ),
                    'price'                => array(
                        'title'       => __('Price', "fs-schema-wordpress"),
                        'type'        => 'number',
                        'recommended' => true,
                        'attr'        => 'step="any"',
                        'desc'        => __("This is highly recommended. The lowest available price, including service charges and fees, of this type of ticket.", "fs-schema-wordpress")
                    ),
                    'priceCurrency'        => array(
                        'title' => __('Price currency', "fs-schema-wordpress"),
                        'type'  => 'text',
                        'desc'  => __("The 3-letter currency code. (USD)", "fs-schema-wordpress")
                    ),
                    'availability'         => array(
                        'title'       => 'Availability',
                        'type'        => 'select',
                        'recommended' => true,
                        'empty'       => "Select one",
                        'options'     => array(
                            'http://schema.org/InStock'  => 'InStock',
                            'http://schema.org/SoldOut'  => 'SoldOut',
                            'http://schema.org/PreOrder' => 'PreOrder',
                        ),
                    ),
                    'validFrom'            => array(
                        'title'       => __('Valid From', "fs-schema-wordpress"),
                        'type'        => 'text',
                        'recommended' => true,
                        'class'       => 'kcseo-date',
                        'desc'        => __(sprintf("The date and time when tickets go on sale (only required on date-restricted offers), in ISO-8601 format"), "fs-schema-wordpress")
                    ),
                )
            ),
            'q&a' => array(
                'title'  => __("Q&A", "fs-schema-wordpress"),
                'fields' => array(
                    'active'               => array(
                        'type' => 'checkbox'
                    ),
                    'name'         => array(
                        'title'    => __('Question', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'required' => true,
                    ),
                    'description'   => array(
                        'title'     => __('Description', "fs-schema-wordpress"),
                        'type'      => 'textarea'
                    ),
                    'answerCount'   => array(
                        'title'     => __('Answer Count', "fs-schema-wordpress"),
                        'type'      => 'text'
                    ),
                    'voteCount'   => array(
                        'title'     => __('Vote Count', "fs-schema-wordpress"),
                        'type'      => 'text'
                    ),
                    'dateCreated'   => array(
                        'title'     => __('Date Created', "fs-schema-wordpress"),
                        'type'      => 'text',
                        'desc'      => __('Like this: 2020-01-01', "fs-schema-wordpress")
                    ),
                    'authorName'    => array(
                        'title'     => __('Author Name', "fs-schema-wordpress"),
                        'type'      => 'text'
                    ),
                    'acc_answer_section'   => array(
                        'title'     => __('Accepted Answer', "fs-schema-wordpress"),
                        'type'      => 'heading'
                    ),
                    'acc_answer'   => array(
                        'title'     => __('Answer', "fs-schema-wordpress"),
                        'type'      => 'text'
                    ),
                    'acc_dateCreated'   => array(
                        'title'     => __('Date Created', "fs-schema-wordpress"),
                        'type'      => 'text',
                        'desc'      => __('Like this: 2020-01-01', "fs-schema-wordpress")
                    ),
                    'acc_voteCount'   => array(
                        'title'     => __('Vote Count', "fs-schema-wordpress"),
                        'type'      => 'text'
                    ),
                    'acc_url'   => array(
                        'title'     => __('URL', "fs-schema-wordpress"),
                        'type'      => 'text'
                    ),
                    'acc_authorName'   => array(
                        'title'     => __('Author Name', "fs-schema-wordpress"),
                        'type'      => 'text'
                    ),
                    'sugg_answer_section'   => array(
                        'title'     => __('Suggested Answer', "fs-schema-wordpress"),
                        'type'      => 'heading'
                    ),
                    'sugg_answer'   => array(
                        'title'     => __('Answer', "fs-schema-wordpress"),
                        'type'      => 'text'
                    ),
                    'sugg_dateCreated'   => array(
                        'title'     => __('Date Created', "fs-schema-wordpress"),
                        'type'      => 'text',
                        'desc'      => __('Like this: 2020-01-01', "fs-schema-wordpress")
                    ),
                    'sugg_voteCount'=> array(
                        'title'     => __('Vote Count', "fs-schema-wordpress"),
                        'type'      => 'text'
                    ),
                    'sugg_url'      => array(
                        'title'     => __('URL', "fs-schema-wordpress"),
                        'type'      => 'text'
                    ),
                    'sugg_authorName'   => array(
                        'title'     => __('Author Name', "fs-schema-wordpress"),
                        'type'      => 'text'
                    ),
                )
            ),
            'softwareApp' => array(
                'title' => __("Software Application", "fs-schema-wordpress"),
                'fields' => array(
                    'active'           => array(
                        'type' => 'checkbox'
                    ),
                    'name'         => array(
                        'title'    => __('Name', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'required' => true,
                        'desc'     => __("The name of the app.", "fs-schema-wordpress")
                    ),
                    'operatingSystem' => array(
                        'title'    => __('Operating System', "fs-schema-wordpress"),
                        'type'     => 'text',
                    ),
                    'applicationCategory'         => array(
                        'title'    => __('Application Category', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'desc'     => __("The type of app (for example, BusinessApplication or GameApplication).", "fs-schema-wordpress")
                    ),
                    'ratingValue'     => array(
                        'title'       => __('Rating Value', "fs-schema-wordpress"),
                        'type'        => 'number',
                        'recommended' => true,
                        'attr'        => 'step="any"',
                    ),
                    'ratingCount'     => array(
                        'title'       => __('Rating count', "fs-schema-wordpress"),
                        'type'        => 'number',
                        'recommended' => true,
                        'attr'        => 'step="any"',
                    ),
                    'price'     => array(
                        'title' => __('Price', "fs-schema-wordpress"),
                        'type'  => 'text',
                        'desc'  => __("Price", "fs-schema-wordpress")
                    ),
                    'priceCurrency'     => array(
                        'title' => __('Price currency', "fs-schema-wordpress"),
                        'type'  => 'text',
                        'desc'  => __("Currency in 3 letter i.e USD, GBP, EUR", "fs-schema-wordpress")
                    ),
                )
            ),
            'newsArticle' => array(
                'title'  => __('News Article', "fs-schema-wordpress"),
                'fields' => array(
                    'active'           => array(
                        'type' => 'checkbox'
                    ),
                    'headline'         => array(
                        'title'    => __('Headline', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'desc'     => __('Article title', "fs-schema-wordpress"),
                        'required' => true
                    ),
                    'mainEntityOfPage' => array(
                        'title'    => __('Page URL', "fs-schema-wordpress"),
                        'type'     => 'url',
                        'desc'     => __('The canonical URL of the article page', "fs-schema-wordpress"),
                        'required' => true
                    ),
                    'author'           => array(
                        'title'    => __('Author', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'desc'     => __('Author display name', "fs-schema-wordpress"),
                        'required' => true
                    ),
                    'image'            => array(
                        'title'    => __('Image', "fs-schema-wordpress"),
                        'type'     => 'image',
                        'desc'     => __("The representative image of the article. Only a marked-up image that directly belongs to the article should be specified.<br> Images should be at least 696 pixels wide. <br>Images should be in .jpg, .png, or. gif format.", "fs-schema-wordpress"),
                        'required' => true
                    ),
                    'datePublished'    => array(
                        'title'    => __('Published date', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'desc'     => __('Like this: 2015-12-25 4:00 PM', "fs-schema-wordpress"),
                        'required' => true
                    ),
                    'dateModified'     => array(
                        'title'    => __('Modified date', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'required' => true,
                        'desc'     => __('Like this: 2015-12-25 4:00 PM', "fs-schema-wordpress")
                    ),
                    'publisher'        => array(
                        'title'    => __('Publisher', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'desc'     => __('Publisher name or Organization name', "fs-schema-wordpress"),
                        'required' => true
                    ),
                    'publisherImage'   => array(
                        'title'    => __('Publisher Logo', "fs-schema-wordpress"),
                        'type'     => 'image',
                        'use'      => 'logo',
                        'desc'     => __('Logos should have a wide aspect ratio, not a square icon.<br>Logos should be no wider than 600px, and no taller than 60px.<br>Always retain the original aspect ratio of the logo when resizing. Ideally, logos are exactly 60px tall with width <= 600px. If maintaining a height of 60px would cause the width to exceed 600px, downscale the logo to exactly 600px wide and reduce the height accordingly below 60px to maintain the original aspect ratio.<br>', "fs-schema-wordpress"),
                        'required' => true
                    ),
                    'description'      => array(
                        'title' => __('Description', "fs-schema-wordpress"),
                        'type'  => 'textarea',
                        'desc'  => __('Short description', "fs-schema-wordpress")
                    ),
                    'articleBody'      => array(
                        'title' => __('Article body', "fs-schema-wordpress"),
                        'type'  => 'textarea',
                        'desc'  => __('Article body content', "fs-schema-wordpress")
                    )
                )
            ),
            'speakable' => array(
                'title'  => __('Speakable', "fs-schema-wordpress"),
                'fields' => array(
                    'active'       => array(
                        'type' => 'checkbox'
                    ),
                    'name'         => array(
                        'title'    => __('Name', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'required' => true,
                        'desc'     => __("The name of the product.", "fs-schema-wordpress")
                    ),
                    'xpath'        => array(
                        'title'    => __('Xpath', "fs-schema-wordpress"),
                        'type'     => 'textarea',
                        'required' => true,
                        'desc'     => __("Addresses content using xPaths (assuming an XML view of the content). Use either cssSelector or xPath; don't use both. For example: /html/head/title.)", "fs-schema-wordpress")
                    ),
                    'url'          => array(
                        'title'    => __('URL', "fs-schema-wordpress"),
                        'type'     => 'text'
                    ),
                )
            ),
            'service'    => array(
                'title'  => __('Service', "fs-schema-wordpress"),
                'fields' => array(
                    'active'           => array(
                        'type' => 'checkbox'
                    ),
                    'name'             => array(
                        'title'    => __('Name', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'required' => true,
                        'desc'     => __("The name of the Service.", "fs-schema-wordpress")
                    ),
                    'serviceType'      => array(
                        'title'    => __('Service type', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'required' => true,
                        'desc'     => __("The type of service being offered, e.g. veterans' benefits, emergency relief, etc.", "fs-schema-wordpress")
                    ),
                    'additionalType'   => array(
                        'title'       => 'Additional type(URL)',
                        'type'        => 'url',
                        'placeholder' => 'URL',
                        'desc'        => __("An additional type for the service, typically used for adding more specific types from external vocabularies in microdata syntax.", "fs-schema-wordpress")
                    ),
                    'award'            => array(
                        'title' => __('Award', "fs-schema-wordpress"),
                        'type'  => 'text',
                        'desc'  => __("An award won by or for this service.", "fs-schema-wordpress")
                    ),
                    'category'         => array(
                        'title' => __('Category', "fs-schema-wordpress"),
                        'type'  => 'text',
                        'desc'  => __("A category for the service.", "fs-schema-wordpress")
                    ),
                    'providerMobility' => array(
                        'title' => __('Provider mobility', "fs-schema-wordpress"),
                        'type'  => 'text',
                        'desc'  => __("Indicates the mobility of a provided service (e.g. 'static', 'dynamic').", "fs-schema-wordpress")
                    ),
                    'description'      => array(
                        'title'   => 'Description',
                        'type'    => 'textarea',
                        'require' => true,
                        'desc'    => __("A short description of the service.", "fs-schema-wordpress")
                    ),
                    'image'            => array(
                        'title'   => 'Image URL',
                        'type'    => 'url',
                        'require' => false,
                        'desc'    => __("An image of the service. This should be a URL.", "fs-schema-wordpress")
                    ),
                    'mainEntityOfPage' => array(
                        'title'   => 'Main entity of page URL',
                        'type'    => 'url',
                        'require' => false,
                        'desc'    => __("Indicates a page (or other CreativeWork) for which this thing is the main entity being described.", "fs-schema-wordpress")
                    ),
                    'sameAs'           => array(
                        'title'       => 'Same as URL',
                        'type'        => 'url',
                        'placeholder' => 'URL',
                        'desc'        => __("URL of a reference Web page that unambiguously indicates the service's identity. E.g. the URL of the service's Wikipedia page, Freebase page, or official website.", "fs-schema-wordpress")
                    ),
                    'url'              => array(
                        'title'       => 'Url of the service',
                        'type'        => 'url',
                        'placeholder' => 'URL',
                        'desc'        => __("URL of the service.", "fs-schema-wordpress")
                    ),
                    'alternateName'    => array(
                        'title' => __('Alternate name', "fs-schema-wordpress"),
                        'type'  => 'text',
                        'desc'  => __('An alias for the service.', "fs-schema-wordpress")
                    ),
                )
            ),
            'restaurant' => array(
                'title'  => __('Restaurant', "fs-schema-wordpress"),
                'fields' => array(
                    'active'           => array(
                        'type' => 'checkbox'
                    ),
                    'name'          => array(
                        'title'    => __('Name of the Restaurant', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'required' => true
                    ),
                    'description'   => array(
                        'title' => __('Description of the Restaurant', "fs-schema-wordpress"),
                        'type'  => 'textarea',
                    ),
                    'openingHours'  => array(
                        'title' => __('Opening Hours', "fs-schema-wordpress"),
                        'type'  => 'textarea',
                        'desc'  => __('Mo,Tu,We,Th,Fr,Sa,Su 11:30-23:00', "fs-schema-wordpress")
                    ),
                    'telephone'     => array(
                        'title' => __('Telephone', "fs-schema-wordpress"),
                        'type'  => 'text',
                        'desc'  => __('+155501003333', "fs-schema-wordpress")
                    ),
                    'menu'          => array(
                        'title' => __('Menu', "fs-schema-wordpress"),
                        'type'  => 'text',
                        'desc'  => __('http://example.com/menu', "fs-schema-wordpress")
                    ),
                    'image'         => array(
                        'title'    => __('Image', "fs-schema-wordpress"),
                        'type'     => 'image',
                        'required' => true
                    ),
                    'address'       => array(
                        'title' => __('Address', "fs-schema-wordpress"),
                        'type'  => 'textarea'
                    ),
                    'priceRange'    => array(
                        'title' => __('Price Range', "fs-schema-wordpress"),
                        'type'  => 'text',
                        'desc'  => __('The price range of the business, for example $$$', "fs-schema-wordpress")
                    ),
                    'servesCuisine' => array(
                        'title' => __('Serves Cuisine', "fs-schema-wordpress"),
                        'type'  => 'text',
                        'desc'  => __('The cuisine of the restaurant.', "fs-schema-wordpress")
                    )
                )
            ),
            'FAQ' => array(
                'title'  => __("FAQ", "fs-schema-wordpress"),
                'fields' => array(
                    'active'               => array(
                        'type' => 'checkbox'
                    ),
                    'question' => array(
                        'type' => 'list_item'
                    ),
                )
            ),
			'reviews' => array(
                'title'  => __("Reviews", "fs-schema-wordpress"),
                'fields' => array(
                    'active'               => array(
                        'type' => 'checkbox'
                    ),
                    'author'       => array(
                        'title'    => __('Author', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'desc'     => __('Author display name', "fs-schema-wordpress"),
                        'required' => true
                    ),
                    'social_url'       => array(
                        'title'    => __('Social Link', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'desc'     => __('Ex: https://plus.google.com/114108465800532712602', "fs-schema-wordpress"),
                    ),
                    'url'       => array(
                        'title'    => __('URL', "fs-schema-wordpress"),
                        'type'     => 'text',
                    ),
                    'datePublished'=> array(
                        'title'    => __('Published Date', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'desc'     => __('Ex: 2020-01-01T20:00', "fs-schema-wordpress"),
                    ),
                    'publisher_name'=> array(
                        'title'    => __('Publisher Name', "fs-schema-wordpress"),
                        'type'     => 'text',
                    ),
                    'reviewed_item_name'=> array(
                        'title'    => __('Name of reviewed item', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'required' => true
                    ),
                    'name'=> array(
                        'title'    => __('Name of review', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'required' => true
                    ),
                    'description'=> array(
                        'title'    => __('Description of review', "fs-schema-wordpress"),
                        'type'     => 'text',
                        'required' => true
                    ),
                    'ratingValue'     => array(
                        'title'       => __('Rating Value', "fs-schema-wordpress"),
                        'type'        => 'number',
                        'recommended' => true,
                        'required'    => true,
                        'desc'        => __('A numerical quality rating for the item.', "fs-schema-wordpress"),
                    ),
                    'bestRating'  => array(
                        'title'       => __('Best rating', "fs-schema-wordpress"),
                        'type'        => 'number',
                        'recommended' => true,
                        'desc'        => __('The highest value allowed in this rating system.', "fs-schema-wordpress"),
                    ),
                    'worstRating'  => array(
                        'title'       => __('Worst rating', "fs-schema-wordpress"),
                        'type'        => 'number',
                        'recommended' => true,
                        'desc'        => __('The lowest value allowed in this rating system. * Required if the rating system is not on a 5-point scale. If worstRating is omitted, 1 is assumed.', "fs-schema-wordpress"),
                    ),
                )
            ),
            'book' => array(
                'title' => __("Book", "fs-schema-wordpress"),
                'pro'   => true
            ),
            'course'    => array(
                'title' => __("Course", "fs-schema-wordpress"),
                'pro'   => true
            ),
            'jobTraining'    => array(
                'title' => __("Job Training", "fs-schema-wordpress"),
                'pro'   => true
            ),
            'movie'     => array(
                'title' => __("Movie", "fs-schema-wordpress"),
                'pro'   => true
            ),
            'occupation' => array(
                'title'  => __("Occupation", "fs-schema-wordpress"),
                'pro'    => true
            ),
            'recipe'    => array(
                'title' => __("Recipe", "fs-schema-wordpress"),
                'pro'   => true
            )
		);
		return apply_filters('fssc_schema_fields', $schemaFields);
	}

	function sanitize( $field = array(), $value = null ) {
		$newValue = null;
		if ( is_array( $field ) && $value ) {
			$type = ( ! empty( $field['type'] ) ? $field['type'] : 'text' );
			if ( $type == 'text' || $type == 'number' || $type == 'select' || $type == 'checkbox' || $type == 'radio' ) {
				$newValue = sanitize_text_field( $value );
			} else if ( $type == 'url' ) {
				$newValue = esc_url( $value );
			} else if ( $type == 'textarea' ) {
				$newValue = wp_kses( $value, array() );
			} else {
				$newValue = sanitize_text_field( $value );
			}
		}
		return $newValue;
	}
}