<?php
if ( ! class_exists( 'FSSC_SchemaFunction' ) ):

	class FSSC_SchemaFunction{
		protected $version;
		function __construct() {
			add_action( 'wp_ajax_addSocialProfile', array( $this, 'addSocialProfile' ) );
			add_action( 'wp_ajax_saveAdvancedSettings', array( $this, 'saveAdvancedSettings' ) );
			add_action( 'wp_ajax_saveSchemaMainSettings', array( $this, 'saveSchemaMainSettings' ) );
			add_action( 'wp_ajax_saveLicenceSettings', array( $this, 'saveLicenceSettings' ) );
		}

		function getSchemaSettingsPost(){
			$settings = get_option('fs_schema_settings', []);
			$display_post_screens = array( 'post', 'page', 'product');
			if(isset($settings['post_type']) && !empty($settings['post_type'])){
              $display_post_screens = array_merge($display_post_screens,array_values($settings['post_type']));
			}
			return $display_post_screens;
		}

	    function isWooCommerceActive() {
		    return class_exists( 'woocommerce' );
	    }

	    public static function getProductAvailibilityList($type) {
            $content="";
			switch ($type){
			    case 'instock':
			        $content = 'http://schema.org/InStock' ;
			        break;
			    case 'outofstock':
			        $content = 'http://schema.org/OutOfStock';
			        break;
			    case 'onbackorder':
			        $content = 'http://schema.org/PreOrder';
			        break;
			    case 'instoreonly':
			        $content = 'http://schema.org/InStoreOnly';
			        break;
			    case 'soldout':
			        $content = 'http://schema.org/SoldOut';
			        break;
			    case 'onlineonly':
			        $content = 'http://schema.org/OnlineOnly';
			        break;
			    case 'limitedavailability':
			        $content = 'http://schema.org/LimitedAvailability';
			        break;
			    case 'discontinued':
			        $content = 'http://schema.org/Discontinued';
			        break;  
			    case 'preorder':
			        $content = 'http://schema.org/PreOrder';
			        break;      
			}
			return $content;
        }

		public static function getSocialList() {
	        $socialList = array(
	            'facebook'    => __('Facebook', "fs-schema-wordpress"),
	            'twitter'     => __('Twitter', "fs-schema-wordpress"),
	            'google-plus' => __('Google+', "fs-schema-wordpress"),
	            'instagram'   => __('Instagram', "fs-schema-wordpress"),
	            'youtube'     => __('Youtube', "fs-schema-wordpress"),
	            'linkedin'    => __('LinkedIn', "fs-schema-wordpress"),
	            'myspace'     => __('Myspace', "fs-schema-wordpress"),
	            'pinterest'   => __('Pinterest', "fs-schema-wordpress"),
	            'soundcloud'  => __('SoundCloud', "fs-schema-wordpress"),
	            'tumblr'      => __('Tumblr', "fs-schema-wordpress"),
	            'wikidata'    => __('Wikidata', "fs-schema-wordpress"),
	            'hasMap'      => __('Map URL', "fs-schema-wordpress")
	        );
	        return $socialList;
    	}

    	function addSocialProfile(){
    		$id          = ( absint($_REQUEST['id']) );
			$html        = null;
			$html        = "<div class='sfield'>";
			$html        .= "<select name='social[$id][id]'>";
			foreach ( $this->getSocialList() as $skey => $social ) {
				$html .= "<option value='$skey'>$social</option>";
			}
			$html .= "</select>";
			$html .= "<input type='text' name='social[$id][link]'>";
			$html .= '<span class="dashicons dashicons-trash social-remove"></span>';
			$html .= "</div>";
			wp_send_json( array( 'data' => $html ) );
			die();
    	}

    	function saveSchemaMainSettings(){
    		$error = true;
			$msg   = null;
			unset( $_REQUEST['action'] );
			$web_url 		= esc_url($_REQUEST['web_url']);
			$business_name 	= sanitize_text_field($_REQUEST['business_name']);
			$site_image 	= sanitize_text_field($_REQUEST['site_image']);
			$site_telephone = preg_replace('/[^0-9]/', '', $_REQUEST['site_telephone']);
			$address 		= fssc_sanitizeInput($_REQUEST['address'], 'text');
			$social 		= fssc_sanitizeInput($_REQUEST['social'], 'url');

			$data = array('web_url' => $web_url, 'business_name' => $business_name, 'site_image' => $site_image, 'site_telephone' => $site_telephone, 'address' => $address, 'social' => $social );
			
			update_option( '_fssc_schema_main_settings', $data );
			$error = false;
			$msg   = __( 'Settings updated !...', "fs-schema-wordpress");
			
			$response = array(
				'error' => $error,
				'msg'   => $msg
			);
			wp_send_json( $response );
			die();
    	}

    	function saveAdvancedSettings(){
    		$error = true;
			$msg   = null;
			unset( $_REQUEST['action'] );
			$data = array('delete_data' => intval($_REQUEST['delete_data']), 
				'yoast_wpseo_json_ld' => intval($_REQUEST['yoast_wpseo_json_ld']), 
				'yoast_wpseo_json_ld_search' => intval($_REQUEST['yoast_wpseo_json_ld_search']), 
				'wc_schema_disable' => intval($_REQUEST['wc_schema_disable']), 
				'edd_schema_microdata' => intval($_REQUEST['edd_schema_microdata']));
			update_option( '_fssc_advanced_settings', $data );
			$error = false;
			$msg   = __( 'Settings updated !...', "fs-schema-wordpress");
			
			$response = array(
				'error' => $error,
				'msg'   => $msg
			);
			wp_send_json( $response );
			die();
    	}

    	function saveLicenceSettings(){
    		$error = true;
			$msg   = null;
			unset( $_REQUEST['action'] );
			$url = FSSC_Action::sampark();
			if(!empty($url)){
				$server_url = $url.'/wp-json/';
				$server = sanitize_text_field($_SERVER['SERVER_NAME']);
				$args = array(
					'headers'     => array('Content-Type' => 'application/json; charset=utf-8'),
				    'body'        => json_encode(array('lkey' => sanitize_text_field($_REQUEST['lic_key']),'email' => sanitize_email($_REQUEST['lic_email']), 'server' => $server)),
				    'method'      => 'POST',
				    'data_format' => 'body'
				);
			    $url = $server_url.'license/activate';
			    $response = wp_remote_post($url,$args);
				$response = $response['body'];

				if (!is_wp_error($response)) {
					$result = json_decode($response);
					if($result->code == 200) {
					    $arr = array("email" => sanitize_email($_REQUEST['lic_email']), 
					    	"license_key" => sanitize_text_field($_REQUEST['lic_key']), 
					    	"domain" => sanitize_text_field($_SERVER['SERVER_NAME']), 
					    	"is_license_verify" => sanitize_text_field($result->license_verify), 
					    	"ip_address" => sanitize_text_field($_SERVER['REMOTE_ADDR']));
					    update_option('_fssc_licence_settings',$arr);
					    $error  = false;
					    $result = array($result->message, $result->license_verify);
					}else{
					    $result = array($result->message, FALSE);
					}
				}else{
					$result = array(__("Something went wrong, Please try again.", "fs-schema-wordpress"),FALSE);
				}
			}
			$response = array(
				'error' => $error,
				'msg'   => $result
			);
			wp_send_json( $response );
			die();
    	}   	
	}
endif;

new FSSC_SchemaFunction();
