<?php

defined('ABSPATH') || exit;

/**
 * Main FSSC Menu initialization Class. 
 *
 * @class FSSC_Init
 */
if ( ! class_exists( 'FSSC_Init' ) ):

	class FSSC_Init {
		protected $version;
		/**
	 	* FSSC_Init Constructor.
	 	*/
		function __construct() {
			add_action( 'admin_menu', array( $this, 'fssc_schema_menu' ) );
			add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_scripts' ) );
			add_action( 'plugins_loaded', array( __CLASS__, 'fssc_disable_plugin_generated_schema' ) );
		}

		function admin_enqueue_scripts() {
			global $pagenow;
			$page = isset( $_REQUEST['page'] ) ? esc_attr($_REQUEST['page']) : null;
			if ( $pagenow == 'admin.php' && $page == 'fs-schema' || $page =='fs-settings' ) {
				wp_enqueue_media();
			}
		}

		function fssc_schema_menu(){
		    add_menu_page( __( 'FS Schema Wordpress', "fs-schema-wordpress" ), __( 'FS Schema', "fs-schema-wordpress" ), 'manage_options', 'fs-schema',  array( $this, 'fssc_schema_page' ), 'dashicons-chart-area');
		    add_submenu_page('fs-schema',  __( 'FS Schema', "fs-schema-wordpress" ),  __( 'General', "fs-schema-wordpress" ), 'manage_options', 'fs-schema' );
		    add_submenu_page('fs-schema',  __( 'FS Schema', "fs-schema-wordpress" ),  __( 'Settings', "fs-schema-wordpress" ), 'manage_options', 'fs-settings' ,array( $this, 'fssc_schema_setting_page' ));
		    add_submenu_page('fs-schema',  __( 'FS Schema', "fs-schema-wordpress" ),  __( 'Licence', "fs-schema-wordpress" ), 'manage_options', 'fs-licence-settings' ,array( $this, 'fssc_licence_setting_page' ));
		}

		function fssc_schema_page(){
			$settings = get_option('_fssc_schema_main_settings'); 
			include FSSC_BASE_DIR.'templates/schema-options.php';
		}

		function fssc_schema_setting_page(){
			$settings = get_option('_fssc_advanced_settings');
			include FSSC_BASE_DIR.'templates/settings.php';
		}

		function fssc_licence_setting_page(){
			include FSSC_BASE_DIR.'templates/licence-setting.php';
		}

		// Disable plugin generated schema
		public static function fssc_disable_plugin_generated_schema(){
			$schema_settings = get_option('_fssc_advanced_settings');
			// Disable YOAST SEO Default Schema JSON-LD
			if(isset($schema_settings['yoast_wpseo_json_ld']) && $schema_settings['yoast_wpseo_json_ld']){
				add_filter('wpseo_json_ld_output', 'fssc_disable_yoast_schema_data', 10, 1);
			}
			// Disable YOAST SEO sitelinks searchbox
			if ( isset( $schema_settings['yoast_wpseo_json_ld_search'] ) && $schema_settings['yoast_wpseo_json_ld_search'] ) {
				add_filter( 'disable_wpseo_json_ld_search', '__return_true' );
			}
			// Woocommerce default schema
			if ( isset( $schema_settings['wc_schema_disable'] ) && $schema_settings['wc_schema_disable'] ) {
				add_action( 'init', array( __CLASS__, 'fssc_remove_output_structured_data' ));
				add_filter( 'woocommerce_structured_data_type_for_page', array( __CLASS__, 'fssc_remove_product_structured_data' ));
			}
			// Easy Digital Download default schema
			if ( isset( $schema_settings['edd_schema_microdata'] ) && $schema_settings['edd_schema_microdata'] ) {
				add_filter( 'edd_add_schema_microdata', '__return_false' );
			}
		}

		function fssc_disable_yoast_schema_data($data){
			$data = array();
			return $data;
		}

		public static function fssc_remove_output_structured_data() {
			if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
    			remove_action( 'wp_footer', array( WC()->structured_data, 'output_structured_data'), 10 ); 
				remove_action( 'woocommerce_email_order_details', array( WC()->structured_data, 'output_email_structured_data'), 30 );
			}
		}

		function fssc_remove_product_structured_data($types){
			if ( ( $index = array_search( 'product', $types ) ) !== false ) {
				unset( $types[ $index ] );
			}
			return $types;
		}
	}
endif;

new FSSC_Init();