<?php
if ( ! class_exists( 'FSSC_Output' ) ):
	class FSSC_Output {
		function __construct(){
			add_action( 'wp_footer', array( $this, 'load_schema' ), 99 );
		}

		function load_schema(){
			$schema       = "";
			$settings     = get_option( '_fssc_schema_main_settings' );
            $post         = get_queried_object();
            if(is_home() || is_front_page()){
                $metaData = array();
                $metaData["@context"] = "http://schema.org/";
                $metaData["@type"]    = "WebSite";
                $author_url           = ( ! empty( esc_url($settings['web_url']) ) ? esc_url($settings['web_url']) : get_home_url() );
				$business_name        = ( ! empty( esc_attr($settings['business_name']) ) ? esc_attr($settings['business_name']) : null );
                $metaData["url"]      = $author_url;
                $metaData["name"]     = esc_attr($settings['business_name']);
                if ( ! empty( $settings['social'] ) && is_array( $settings['social'] ) ) {
                    $link = array();
                    foreach ( $settings['social'] as $socialD ) {
                        if ( $socialD['link'] && $socialD['id']!='hasMap') {
                            $link[] = esc_url($socialD['link']);
                        }
                    }
                    if ( ! empty( $link ) ) {
                        $metaData["sameAs"] = $link;
                    }
                }
                if (!empty($settings['address'])) {
                    $metaData['address'] = array(
                        "@type"           => "PostalAddress",
                        "streetAddress"   => esc_attr($settings['address']['street']),
                        "addressLocality" => esc_attr($settings['address']['locality']),
                        "addressRegion"   => esc_attr($settings['address']['region']),
                        "postalCode"      => esc_attr($settings['address']['postalcode']),
                    );
                }
                if ( ! empty( $settings['social'] ) && is_array( $settings['social'] ) ) {
                    foreach ( $settings['social'] as $socialD ) {
                        if ( $socialD['link'] && $socialD['id']=='hasMap') {
                            $metaData['hasMap'] = array(
                                "@type" => "Map",
                                "url"   => esc_url($socialD['link'])
                            );  
                        }
                    }
                }
                
                $schema .= $this->get_jsonEncode( $metaData );
            }
			if ( is_single() || is_page() ) {
				$schemaFields = new FSSC_Fields;
				foreach($schemaFields->getSchemaFields() as $key => $value){
					$schemaMetaId = 'fssc_' . $key;
					$metaData     = get_post_meta( $post->ID, $schemaMetaId, true );
					$metaData     = ( is_array( $metaData ) ? $metaData : array() );
					if ( ! empty( $metaData ) && ! empty( $metaData['active'] ) ) {
						$schema .= $this->fssc_schema_output($key, $metaData);
					}
				}
			}
            echo $schema; 
		}

		function fssc_schema_output($schemaID, $metaData){
			$schema = '';
			if($schemaID){
				switch ($schemaID){
					// Article
					case 'article':
						$article = array(
                            "@context" => "http://schema.org",
                            "@type"    => "Article"
                        );
                        if (!empty($metaData['headline'])) {
                            $article["headline"] = esc_attr($metaData['headline']);
                        }
                        if (!empty($metaData['mainEntityOfPage'])) {
                            $article["mainEntityOfPage"] = array(
                                "@type" => "WebPage",
                                "@id"   => esc_url($metaData["mainEntityOfPage"])
                            );
                        }
                        if (!empty($metaData['author'])) {
                            $article["author"] = array(
                                "@type" => "Person",
                                "name"  => esc_attr($metaData['author'])
                            );
                        }
                        if (!empty($metaData['publisher'])) {
                            if (!empty($metaData['publisherImage'])) {
                            	$ImageId 	= (!empty($metaData['publisherImage']) ? absint($metaData['publisherImage']) : 0);
                            	$imgData    = wp_get_attachment_metadata( $ImageId );
                            	$url 		= wp_get_attachment_url( $ImageId, 'full' );
                                $plA 		= array(
                                    "@type"  => "ImageObject",
                                    "url"    => $url,
                                    "height" => (! empty( $imgData['height'] ) ? absint( $imgData['height'] ) : 0),
                                    "width"  => (! empty( $imgData['width'] ) ? absint( $imgData['width'] ) : 0)
                                );
                            } else {
                                $plA = array();
                            }
                            $article["publisher"] = array(
                                "@type" => "Organization",
                                "name"  => esc_attr($metaData['publisher']),
                                "logo"  => $plA
                            );
                        }
                        if (!empty($metaData['image'])) {
                            $ImageId = (!empty($metaData['image']) ? absint($metaData['image']) : 0);
                            $imgData    = wp_get_attachment_metadata( $ImageId );
                            $url 		= wp_get_attachment_url( $ImageId, 'full' );
                            $article["image"] = array(
                                "@type"  => "ImageObject",
                                "url"    => $url,
                                "height" => (! empty( $imgData['height'] ) ? absint( $imgData['height'] ) : 0),
                                "width"  => (! empty( $imgData['width'] ) ? absint( $imgData['width'] ) : 0)
                            );
                        }
                        if (!empty($metaData['datePublished'])) {
                            $article["datePublished"] = esc_attr($metaData['datePublished']);
                        }
                        if (!empty($metaData['dateModified'])) {
                            $article["dateModified"] = esc_attr($metaData['dateModified']);
                        }
                        if (!empty($metaData['description'])) {
                            $article["description"] = esc_textarea($metaData['description']);
                        }
						$schema .= $this->get_jsonEncode(apply_filters('fssc_snippet_article', $article, $metaData));
                    break;
                    // Product
                    case 'product' :
                    	$product = array(
                            "@context" => "https://schema.org",
                            "@type"    => "Product"
                        );
                        if (!empty($metaData['name'])) {
                            $product["name"] = esc_attr($metaData['name']);
                        }
                        if (!empty($metaData['image'])) {
                            $ImageId = (!empty($metaData['image']) ? absint($metaData['image']) : 0);
                            $url 		= wp_get_attachment_url( $ImageId, 'full' );
                            $product["image"] = $url;
                        }
                        if (!empty($metaData['description'])) {
                            $product["description"] = $metaData['description'];
                        }
                        if (!empty($metaData['sku'])) {
                            $product["sku"] = esc_attr($metaData['sku']);
                        }
                        if (!empty($metaData['brand'])) {
                            $product["brand"] = array(
                            	"@type" => "Thing",
                            	"name" => esc_attr($metaData['brand'])
                            );
                        }
                        if (!empty($metaData['identifier_type']) && !empty($metaData['identifier'])) {
                            $product[$metaData['identifier_type']] = esc_attr($metaData['identifier']);
                        }
                        if (!empty($metaData['ratingValue'])) {
                            $product["aggregateRating"] = array(
                                "@type"       => "AggregateRating",
                                "ratingValue" => !empty($metaData['ratingValue']) ? esc_attr($metaData['ratingValue']) : null,
                                "reviewCount" => !empty($metaData['ratingCount']) ? esc_attr($metaData['ratingCount']) : null
                            );
                        }
                        if (!empty($metaData['reviewRatingValue']) || !empty($metaData['reviewBestRating']) || !empty($metaData['reviewWorstRating'])) {
                            $product["review"] = array(
                                "@type"        => "Review",
                                "reviewRating" => array(
                                    "@type"       => "Rating",
                                    "ratingValue" => !empty($metaData['reviewRatingValue']) ? esc_attr($metaData['reviewRatingValue']) : null,
                                    "bestRating"  => !empty($metaData['reviewBestRating']) ? esc_attr($metaData['reviewBestRating']) : null
                                ),
                                "author"       => array(
                                    "@type" => "Person",
                                    "name"  => !empty($metaData['reviewAuthor']) ? esc_attr($metaData['reviewAuthor']) : null
                                )
                            );
                        }
                        if (!empty($metaData['price'])) {
                            $product["offers"] = array(
                                "@type"           => "Offer",
                                "price"           => $metaData['price'],
                                "priceValidUntil" => $metaData['priceValidUntil'],
                                "priceCurrency"   => !empty($metaData['priceCurrency']) ? esc_attr($metaData['priceCurrency']) : null,
                                "itemCondition"   => !empty($metaData['itemCondition']) ? esc_attr($metaData['itemCondition']) : null,
                                "availability"    => !empty($metaData['availability']) ? esc_url($metaData['availability']) : null,
                                "url"             => !empty($metaData['url']) ? esc_url($metaData['url']) : null
                            );
                        }
                        $schema .= $this->get_jsonEncode(apply_filters('fssc_snippet_product', $product, $metaData));
                    break;                    
                    // Video
                    case 'video':
                        $video = array(
                            "@context" => "http://schema.org",
                            "@type"    => "VideoObject"
                        );
                        if (!empty($metaData['name'])) {
                            $video["name"] = esc_attr($metaData['name']);
                        }
                        if (!empty($metaData['description'])) {
                            $video["description"] = esc_textarea($metaData['description']);
                        }
                        if (!empty($metaData['thumbnailUrl'])) {
                            $video["thumbnailUrl"] = esc_url($metaData['thumbnailUrl']);
                        }
                        if (!empty($metaData['uploadDate'])) {
                            $video["uploadDate"] = esc_attr($metaData['uploadDate']);
                        }
                        if (!empty($metaData['duration'])) {
                            $video["duration"] = esc_attr($metaData['duration']);
                        }
                        if (!empty($metaData['contentUrl'])) {
                            $video["contentUrl"] = esc_url($metaData['contentUrl']);
                        }
                        if (!empty($metaData['embedUrl'])) {
                            $video["embedUrl"] = esc_url($metaData['embedUrl']);
                        }
                        if (!empty($metaData['interactionCount'])) {
                            $video["interactionCount"] = esc_attr($metaData['interactionCount']);
                        }
                        if (!empty($metaData['expires'])) {
                            $video["expires"] = esc_attr($metaData['expires']);
                        }
                        $schema .= $this->get_jsonEncode(apply_filters('fssc_snippet_video', $video, $metaData));
                    break;
                    // LocalBusiness
                    case 'localBusiness':
                        $localBusiness = array(
                            "@context" => "http://schema.org",
                            "@type"    => "LocalBusiness"
                        );
                        if (!empty($metaData['name'])) {
                            $localBusiness["name"] = esc_attr($metaData['name']);
                        }
                        if (!empty($metaData['description'])) {
                            $localBusiness["description"] = esc_textarea($metaData['description']);
                        }
                        if (!empty($metaData['image'])) {
                            $localBusiness["image"] = esc_url($metaData['image']);
                        }
                        if (!empty($metaData['streetAddress'])) {
                        	$localBusiness['address'] = array(
                        		"@type"    		  => "PostalAddress",
                        		"streetAddress"   => esc_attr($metaData['streetAddress']),
                        		"addressLocality" => esc_attr($metaData['addressLocality']),
                        		"addressRegion"   => esc_attr($metaData['addressRegion']),
                        		"postalCode" 	  => esc_attr($metaData['postalCode']),
                        	);
                        }
                        if (!empty($metaData['telephone'])) {
                        	$localBusiness["telephone"] = esc_attr($metaData['telephone']);
                        }
                        if (!empty($metaData['map'])) {
                            $localBusiness["hasMap"] = array(
                                "@type" => "Map",
                                "url"   => esc_url($metaData['map'])
                            );
                        }
                        if (!empty($metaData['priceRange'])) {
                        	$localBusiness["priceRange"] = esc_attr($metaData['priceRange']);
                        }
                    	$schema .= $this->get_jsonEncode(apply_filters('fssc_snippet_localBusiness', $localBusiness, $metaData));
                    break;
                    // Job Posting
                    case 'JobPosting':
                    	$jobposting = array(
                            "@context" => "http://schema.org",
                            "@type"    => "JobPosting"
                        );
                    	if (!empty($metaData['title'])) {
                            $jobposting["title"] = esc_attr($metaData['title']);
                        }
                        if (!empty($metaData['description'])) {
                            $jobposting["description"] = esc_textarea($metaData['description']);
                        }
                        if (!empty($metaData['identifier_name'])) {
                            $jobposting["identifier"] = array(
                            	"@type"    	=> "PropertyValue",
                            	"name" 		=> esc_attr($metaData['identifier_name']),
                            	"value" 	=> esc_attr($metaData['identifier_value'])
                            );
                        }
                        if (!empty($metaData['datePosted'])) {
                            $jobposting["datePosted"] = esc_attr($metaData['datePosted']);
                        }
                        if (!empty($metaData['validThrough'])) {
                            $jobposting["validThrough"] = esc_attr($metaData['validThrough']);
                        }
                        if (!empty($metaData['employmentType'])) {
                            $jobposting["employmentType"] = esc_attr($metaData['employmentType']);
                        }
                        if (!empty($metaData['organization_name'])) {
                        	$ImageId  = (!empty($metaData['image']) ? absint($metaData['image']) : 0);
                            $url 	  = wp_get_attachment_url( $ImageId, 'full' );
                            $jobposting["hiringOrganization"] = array(
                            	"@type"   => "Organization",
                            	"name" 	  => $metaData['organization_name'],
                            	"sameAs"  => $metaData['sameAs'],
                            	"logo"    => $url
                            );
                        }
                        if (!empty($metaData['streetAddress'])) {
                        	$jobposting["jobLocation"] = array(
                        		"@type"           => "Place",
                        		"address"         => array(
                        			"@type"           => "PostalAddress",
                        			"streetAddress"   => esc_attr($metaData['streetAddress']),
                        			"addressLocality" => esc_attr($metaData['addressLocality']),
                        			"addressRegion"   => esc_attr($metaData['addressRegion']),
                        			"postalCode"      => esc_attr($metaData['postalCode']),
                        			"addressCountry"  => esc_attr($metaData['addressCountry'])
                        		)
                        	);
                        }
                        if (!empty($metaData['currency'])) {
                        	$jobposting["baseSalary"] = array(
                        		"@type"     => "MonetaryAmount",
                        		"currency"  => esc_attr($metaData['streetAddress']),
                        		"value"     => array(
                        			"@type"    => "QuantitativeValue",
                        			"value"    => esc_attr($metaData['salary']),
                        			"unitText" => esc_attr($metaData['unitText'])
                        		)
                        	);
                        }
                    	$schema .= $this->get_jsonEncode(apply_filters('fssc_snippet_jobposting', $jobposting, $metaData));
                    break;
                    // Event
                    case 'event':
                        $event = array(
                            "@context" => "http://schema.org",
                            "@type"    => "Event"
                        );
                        if (!empty($metaData['name'])) {
                            $event["name"] = esc_attr($metaData['name']);
                        }
                        if (!empty($metaData['startDate'])) {
                            $event["startDate"] = esc_attr($metaData['startDate']);
                        }
                        if (!empty($metaData['endDate'])) {
                            $event["endDate"] = esc_attr($metaData['endDate']);
                        }
                        if (!empty($metaData['description'])) {
                            $event["description"] = esc_textarea($metaData['description']);
                        }
                        if (!empty($metaData['performerName'])) {
                            $event["performer"] = array(
                                "@type" => "Person",
                                "name"  => esc_attr($metaData['performerName'])
                            );
                        }
                        if (!empty($metaData['image'])) {
                            $event["image"] = esc_url($metaData['image']);
                        }
                        if (!empty($metaData['locationName'])) {
                            $event["location"] = array(
                                "@type"   => "Place",
                                "name"    => esc_attr($metaData['locationName']),
                                "address" => esc_attr($metaData['locationAddress'])
                            );
                        }
                        if (!empty($metaData['price'])) {
                            $event["offers"] = array(
                                "@type" => "Offer",
                                "price" => esc_attr($metaData['price'])
                            );
                            if (!empty($metaData['priceCurrency'])) {
                                $event["offers"]['priceCurrency'] = esc_attr($metaData['priceCurrency']);
                            }
                            if (!empty($metaData['url'])) {
                                $event["offers"]['url'] = esc_url($metaData['url']);
                            }
                            if (!empty($metaData['availability'])) {
                                $event["offers"]['availability'] = esc_attr($metaData['availability']);
                            }
                            if (!empty($metaData['validFrom'])) {
                                $event["offers"]['validFrom'] = esc_attr($metaData['validFrom']);
                            }
                        }
                        if (!empty($metaData['url'])) {
                            $event["url"] = esc_attr($metaData['url']);
                        }
                        $schema .= $this->get_jsonEncode(apply_filters('fssc_snippet_event', $event, $metaData));
                    break;
                    // Q&A
                    case "q&a" :
                    	$qa = array(
                            "@context" => "http://schema.org",
                            "@type"    => "QAPage"
                        );
                    	if (!empty($metaData['name'])) {
                            $qa["mainEntity"] = array(
                            	"@type"    => "Question",
                            	"name"     => esc_attr($metaData['name'])
                            );
                        }
                         if (!empty($metaData['description'])) {
                            $qa["mainEntity"]["text"] = esc_textarea($metaData['description']);
                        }
                    	if (!empty($metaData['answerCount'])) {
                            $qa["mainEntity"]["answerCount"] = esc_attr($metaData['answerCount']);
                        }
                        if (!empty($metaData['voteCount'])) {
                            $qa["mainEntity"]["upvoteCount"] = esc_attr($metaData['voteCount']);
                        }
                        if (!empty($metaData['dateCreated'])) {
                            $qa["mainEntity"]["dateCreated"] = esc_attr($metaData['dateCreated']);
                        }
                        if (!empty($metaData['authorName'])) {
                            $qa["mainEntity"]["author"] = array(
                                "@type" => "Person",
                                "name"  => esc_attr($metaData['authorName'])
                            );
                        }
                        if (!empty($metaData['acc_answer'])) {
                        	$qa["mainEntity"]["acceptedAnswer"] = array(
	                        	"@type" 		=> "Answer",
	                        	"text" 			=> esc_attr($metaData['acc_answer']),
	                        	"dateCreated" 	=> esc_attr($metaData['acc_dateCreated']),
	                        	"upvoteCount" 	=> esc_attr($metaData['acc_voteCount']),
	                        	"url" 			=> esc_url($metaData['acc_url']),
	                        	"author" 		=>  array(
	                        		"@type" => "Person",
	                                "name"  => esc_attr($metaData['acc_authorName'])
	                        	),
                        	);
                        }
                        if (!empty($metaData['sugg_answer'])) {
                        	$qa["mainEntity"]["suggestedAnswer"] = array(
	                        	"@type" 		=> "Answer",
	                        	"text" 			=> esc_attr($metaData['sugg_answer']),
	                        	"dateCreated" 	=> esc_attr($metaData['sugg_dateCreated']),
	                        	"upvoteCount" 	=> esc_attr($metaData['sugg_voteCount']),
	                        	"url" 			=> esc_url($metaData['sugg_url']),
	                        	"author" 		=>  array(
	                        		"@type" => "Person",
	                                "name"  => esc_attr($metaData['sugg_authorName'])
	                        	)
                        	);
                        }
                    	$schema .= $this->get_jsonEncode(apply_filters('fssc_snippet_qa',$qa,$metaData));
                    break;
                    // Software Application
                    case "softwareApp" :
                    	$software_app = array(
                    		"@context" => "http://schema.org",
                            "@type"    => "SoftwareApplication"
                    	);
                    	if (!empty($metaData['name'])) {
                            $software_app["name"] = esc_attr($metaData['name']);
                        }
                        if (!empty($metaData['operatingSystem'])) {
                            $software_app["operatingSystem"] = esc_attr($metaData['operatingSystem']);
                        }
                        if (!empty($metaData['applicationCategory'])) {
                            $software_app["applicationCategory"] = esc_url("https://schema.org/".$metaData['applicationCategory']);
                        }
                        if(!empty($metaData['ratingValue'])){
                        	$software_app["aggregateRating"] = array(
                    			"@type" => "AggregateRating",
                    			"ratingValue" => esc_attr($metaData['ratingValue']),
                    			"ratingCount" => esc_attr($metaData['ratingCount'])
                        	);
                        }
                        if (!empty($metaData['price'])) {
                            $software_app["offers"] = array(
                                "@type"           => "Offer",
                                "price"           => esc_attr($metaData['price']),
                                "priceCurrency"   => esc_attr($metaData['priceCurrency'])
                            );
                        }
                    	$schema .= $this->get_jsonEncode(apply_filters('fssc_snippet_software_app', $software_app, $metaData));
                    break;
                    // News Article
                    case "newsArticle" :
                    	$newsArticle = array(
                            "@context" => "http://schema.org",
                            "@type"    => "NewsArticle"
                        );
                        if (!empty($metaData['headline'])) {
                            $newsArticle["headline"] = esc_attr($metaData['headline']);
                        }
                        if (!empty($metaData['mainEntityOfPage'])) {
                            $newsArticle["mainEntityOfPage"] = array(
                                "@type" => "WebPage",
                                "@id"   => esc_url($metaData["mainEntityOfPage"])
                            );
                        }
                        if (!empty($metaData['author'])) {
                            $newsArticle["author"] = array(
                                "@type" => "Person",
                                "name"  => esc_attr($metaData['author'])
                            );
                        }
                        if (!empty($metaData['image'])) {
                            $ImageId = (!empty($metaData['image']) ? absint($metaData['image']) : 0);
                            $imgData    = wp_get_attachment_metadata( $ImageId );
                            $url 		= wp_get_attachment_url( $ImageId, 'full' );
                            $newsArticle["image"] = array(
                                "@type"  => "ImageObject",
                                "url"    => $url,
                                "height" => (! empty( $imgData['height'] ) ? absint( $imgData['height'] ) : 0),
                                "width"  => (! empty( $imgData['width'] ) ? absint( $imgData['width'] ) : 0)
                            );
                        }
                        if (!empty($metaData['datePublished'])) {
                            $newsArticle["datePublished"] = esc_attr($metaData['datePublished']);
                        }
                        if (!empty($metaData['dateModified'])) {
                            $newsArticle["dateModified"] = esc_attr($metaData['dateModified']);
                        }
                        if (!empty($metaData['publisher'])) {
                            if (!empty($metaData['publisherImage'])) {
                                $ImageId = (!empty($metaData['image']) ? absint($metaData['publisherImage']) : 0);
	                            $imgData    = wp_get_attachment_metadata( $ImageId );
	                            $url 		= wp_get_attachment_url( $ImageId, 'full' );
	                            $plA 		= array(
	                                "@type"  => "ImageObject",
	                                "url"    => $url,
	                                "height" => (! empty( $imgData['height'] ) ? absint( $imgData['height'] ) : 0),
	                                "width"  => (! empty( $imgData['width'] ) ? absint( $imgData['width'] ) : 0)
	                            );
                            } else {
                                $plA = array();
                            }
                            $newsArticle["publisher"] = array(
                                "@type" => "Organization",
                                "name"  => esc_attr($metaData['publisher']),
                                "logo"  => $plA
                            );
                        }
                        if (!empty($metaData['description'])) {
                            $newsArticle["description"] = esc_textarea($metaData['description']);
                        }
                        if (!empty($metaData['articleBody'])) {
                            $newsArticle["articleBody"] = esc_attr($metaData['articleBody']);
                        }
                        $schema .= $this->get_jsonEncode(apply_filters('fssc_snippet_news_article', $newsArticle, $metaData));
                    break;
                    // Speakable
                    case "speakable" :
                    	$speakable = array(
                            "@context" => "http://schema.org",
                            "@type"    => "WebPage"
                        );
                        if (!empty($metaData['xpath'])) {
                            $speakable["speakable"] = array(
                            	"@type" => "SpeakableSpecification",
                            	"xpath" => esc_textarea($metaData['xpath'])
                            );
                        }
                        if (!empty($metaData['url'])) {
                            $speakable["url"] = esc_url($metaData['url']);
                        }
                    	$schema .= $this->get_jsonEncode(apply_filters('fssc_snippet_speakable', $speakable, $metaData));
                    break;
                    // Service
                    case 'service':
                        $service = array(
                            "@context" => "http://schema.org",
                            "@type"    => "Service"
                        );
                        if (!empty($metaData['name'])) {
                            $service["name"] = esc_attr($metaData['name']);
                        }
                        if (!empty($metaData['serviceType'])) {
                            $service["serviceType"] = esc_attr($metaData['serviceType']);
                        }
                        if (!empty($metaData['award'])) {
                            $service["award"] = esc_attr($metaData['award']);
                        }
                        if (!empty($metaData['category'])) {
                            $service["category"] = esc_attr($metaData['category']);
                        }
                        if (!empty($metaData['providerMobility'])) {
                            $service["providerMobility"] = esc_attr($metaData['providerMobility']);
                        }
                        if (!empty($metaData['additionalType'])) {
                            $service["additionalType"] = esc_url($metaData['additionalType']);
                        }
                        if (!empty($metaData['alternateName'])) {
                            $service["alternateName"] = esc_attr($metaData['alternateName']);
                        }
                        if (!empty($metaData['image'])) {
                            $service["image"] = esc_attr($metaData['image']);
                        }
                        if (!empty($metaData['mainEntityOfPage'])) {
                            $service["mainEntityOfPage"] = esc_url($metaData['mainEntityOfPage']);
                        }
                        if (!empty($metaData['sameAs'])) {
                            $service["sameAs"] = esc_url($metaData['sameAs']);
                        }
                        if (!empty($metaData['url'])) {
                            $service["url"] = esc_url($metaData['url']);
                        }
                        $schema .= $this->get_jsonEncode(apply_filters('fssc_snippet_service', $service, $metaData));
                    break;
                    // Restaurant
                    case 'restaurant':
                        $restaurant = array(
                            "@context" => "http://schema.org",
                            "@type"    => "Restaurant"
                        );
                        if (!empty($metaData['name'])) {
                            $restaurant["name"] = esc_attr($metaData['name']);
                        }
                        if (!empty($metaData['description'])) {
                            $restaurant["description"] = esc_textarea($metaData['description']);
                        }
                        if (!empty($metaData['openingHours'])) {
                            $restaurant["openingHours"] = esc_attr($metaData['openingHours']);
                        }
                        if (!empty($metaData['telephone'])) {
                            $restaurant["telephone"] = esc_attr($metaData['telephone']);
                        }
                        if (!empty($metaData['menu'])) {
                            $restaurant["menu"] = esc_url($metaData['menu']);
                        }
                        if (!empty($metaData['image'])) {
                            $ImageId = (!empty($metaData['image']) ? absint($metaData['image']) : 0);
                            $imgData    = wp_get_attachment_metadata( $ImageId );
                            $url 		= wp_get_attachment_url( $ImageId, 'full' );
                            $restaurant["image"] = array(
                                "@type"  => "ImageObject",
                                "url"    => $url,
                                "height" => (! empty( $imgData['height'] ) ? absint( $imgData['height'] ) : 0),
                                "width"  => (! empty( $imgData['width'] ) ? absint( $imgData['width'] ) : 0)
                            );
                        }
                        if (!empty($metaData['address'])) {
                            $restaurant["address"] = esc_textarea($metaData['address']);
                        }
                        if (!empty($metaData['priceRange'])) {
                            $restaurant["priceRange"] = esc_attr($metaData['priceRange']);
                        }
                        if (!empty($metaData['servesCuisine'])) {
                            $restaurant["servesCuisine"] = esc_attr($metaData['servesCuisine']);
                        }
                        $schema .= $this->get_jsonEncode(apply_filters('fssc_snippet_restaurant', $restaurant, $metaData));
                    break;
                    // FAQ
                    case 'FAQ':
                    	$faq = array(
	                        "@context" => "http://schema.org",
	                        "@type"    => "FAQPage"
                        );
                        if (!empty($metaData['question'])) {
                        	$faq["mainEntity"] = array();
                        	foreach( $metaData['question'] as $key => $value){
                        		$faq["mainEntity"][] = array(
                        			"@type"    => "Question",
                        			"name"     => esc_attr($value['question']),
                        			"acceptedAnswer" => array(
                        				"@type"    => "Answer",
                        				"text"     => esc_textarea($value['answer'])
                        			)
                        		);

                        	}
                        }
                        $schema .= $this->get_jsonEncode(apply_filters('fssc_snippet_faq', $faq, $metaData));
                    break;

                    case "reviews" :
                        $reviews = array(
                            "@context" => "http://schema.org",
                            "@type"    => "Review"
                        );
                        if (!empty($metaData['author'])) {
                            $reviews["author"] = array( 
                                "@type"  => "Person",
                                "name"   => esc_attr($metaData['author']),
                                "sameAs" => esc_url($metaData['social_url'])
                            );

                        }
                        if (!empty($metaData['url'])) {
                            $reviews["url"] = esc_url($metaData['url']);
                        }
                        if (!empty($metaData['datePublished'])) {
                            $reviews["datePublished"] = esc_attr($metaData['datePublished']);
                        }
                        if (!empty($metaData['publisher_name'])) {
                            $reviews["publisher"] = array(
                                "@type"  => "Organization",
                                "name"   => esc_attr($metaData['publisher_name'])
                            );
                        }
                        if (!empty($metaData['description'])) {
                            $reviews["description"] = esc_textarea($metaData['description']);
                        }
                        if (!empty($metaData['reviewed_item_name'])) {
                            $reviews["itemReviewed"] = array(
                                "@type"  => esc_attr($metaData['reviewed_item_name']),
                                "name"   => esc_attr($metaData['name'])
                            );
                        }
                        if (!empty($metaData['ratingValue'])) {
                            $reviews["reviewRating"] = array(
                                "@type"  => "Rating",
                                "worstRating" => esc_attr($metaData['worstRating']),
                                "bestRating"  => esc_attr($metaData['bestRating']),
                                "ratingValue" => esc_attr($metaData['ratingValue'])
                            );
                        }
                        $schema .= $this->get_jsonEncode(apply_filters('fssc_snippet_reviews', $reviews, $metaData));
                    break;
				}
			}
			return $schema;
		}

		function get_jsonEncode($data = array()){
			$html = '';
            /** @var TYPE_NAME $data */
            if (!empty($data) && is_array($data)) {
                $html .= '<script type="application/ld+json">' . json_encode($data,
                        JSON_PRETTY_PRINT | JSON_UNESCAPED_SLASHES) . '</script>';
            }
            return $html;
		}
	}
endif;

new FSSC_Output();
